package com.phm.manage.service.impl;

import com.phm.manage.domain.Sortie;
import com.phm.manage.mapper.SortieMapper;
import com.phm.manage.service.ISortieService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 架次信息Service业务层处理
 *
 * @author phm
 * @date 2023-08-22
 */
@Service
public class SortieServiceImpl implements ISortieService {
    @Autowired
    private SortieMapper sortieMapper;

    /**
     * 查询架次信息
     *
     * @param id 架次信息主键
     * @return 架次信息
     */
    @Override
    public Sortie selectSortieById(Long id) {
        return sortieMapper.selectSortieById(id);
    }

    /**
     * 查询架次信息列表
     *
     * @param sortie 架次信息
     * @return 架次信息
     */
    @Override
    public List<Sortie> selectSortieList(Sortie sortie) {
        return sortieMapper.selectSortieList(sortie);
    }

    /**
     * 新增架次信息
     *
     * @param sortie 架次信息
     * @return 结果
     */
    @Override
    public int insertSortie(Sortie sortie) {
        sortie.initCreatInfo();
        return sortieMapper.insertSortie(sortie);
    }

    /**
     * 修改架次信息
     *
     * @param sortie 架次信息
     * @return 结果
     */
    @Override
    public int updateSortie(Sortie sortie) {
        sortie.initUpdateInfo();
        return sortieMapper.updateSortie(sortie);
    }

    /**
     * 批量删除架次信息
     *
     * @param ids 需要删除的架次信息主键
     * @return 结果
     */
    @Override
    public int deleteSortieByIds(Long[] ids) {
        return sortieMapper.deleteSortieByIds(ids);
    }

    /**
     * 删除架次信息信息
     *
     * @param id 架次信息主键
     * @return 结果
     */
    @Override
    public int deleteSortieById(Long id) {
        return sortieMapper.deleteSortieById(id);
    }
}
